import Text.Pandoc.Definition
import qualified Data.Map.Strict as Map
import Text.Pandoc.JSON
import Data.Text (Text)
import Misc

-- | adds the slugs to the tags in a post
--
-- the fact this program doesn't look at @all-tags.md@ is the reason clashing
-- slugs blow up instead of doing something better. i'll just rename one tag,
-- it's fine.
main :: IO ()
main = toJSONFilter \(Pandoc (Meta m) body) -> do
  m' <- Map.alterF addSlugs "tags" m
  pure $ Pandoc (Meta m') body

-- | if @tags@ exists and is a list of strings, add the slugs. if it exists and
-- is something else, explode
addSlugs :: Maybe MetaValue -> IO (Maybe MetaValue)
addSlugs Nothing = pure Nothing
addSlugs (Just (toTextList -> Just tags)) =
  pure $ Just $ MetaList $ map addSlug1 tags
addSlugs (Just t) = fail $
  "'tags' is\n" <> show t <> "\nwanted a list of strings"

addSlug1 :: Text -> MetaValue
addSlug1 tag = MetaMap $ Map.fromList
  [("name", MetaString tag), ("slug", MetaString $ makeSlug tag)]
